@@ -64,11 +64,11 @@ setMethod("t", signature(x = "dgCMatrix"),
 
 setMethod("image", "dgCMatrix",
           function(x, ...) {
-              x = as(x, "dgTMatrix")
+              x <- as(x, "dgTMatrix")
               callGeneric()
           })
 
 setMethod("%*%", signature(x = "dgCMatrix", y = "dgeMatrix"),
-          function(x, y) .Call("dgCMatrix_matrix_mm", x, y, TRUE, FALSE),
+          function(x, y) .Call("csc_matrix_mm", x, y, TRUE, FALSE),
           valueClass = "dgeMatrix")
 
