@@ -36,4 +36,14 @@ SEXP
     Matrix_statusSym,
     Matrix_uploSym,
     Matrix_xSym,
-    Matrix_zSym;
+    Matrix_zSym,
+
+    /* added by deepayan */
+    Matrix_REMLSym,
+    Matrix_callSym,
+    Matrix_termsSym,
+    Matrix_assignSym,
+    Matrix_fittedSym,
+    Matrix_residualsSym,
+    Matrix_frameSym;
+
